@@ -666,6 +666,7 @@ pub struct DBQuery<'q> {
     pub mssql: Option<Query<'q, Mssql, MssqlArguments>>,
 }
 
+
 impl<'q> DBQuery<'q> {
     pub fn bind_value(&mut self, t: &serde_json::Value) -> crate::Result<()> {
         match &self.driver_type {
@@ -680,7 +681,7 @@ impl<'q> DBQuery<'q> {
                         q = q.bind(Some(s.to_owned()));
                     }
                     serde_json::Value::Null => {
-                        q = q.bind(Option::<String>::None);
+                        q = q.bind(Option::<i32>::None);
                     }
                     serde_json::Value::Number(n) => {
                         if n.is_f64() {
@@ -708,7 +709,7 @@ impl<'q> DBQuery<'q> {
                         q = q.bind(Some(s.to_owned()));
                     }
                     serde_json::Value::Null => {
-                        q = q.bind(Option::<String>::None);
+                        q = q.bind(Option::<i32>::None);
                     }
                     serde_json::Value::Number(n) => {
                         if n.is_f64() {
@@ -736,7 +737,7 @@ impl<'q> DBQuery<'q> {
                         q = q.bind(Some(s.to_owned()));
                     }
                     serde_json::Value::Null => {
-                        q = q.bind(Option::<String>::None);
+                        q = q.bind(Option::<i32>::None);
                     }
                     serde_json::Value::Number(n) => {
                         if n.is_f64() {
@@ -764,7 +765,7 @@ impl<'q> DBQuery<'q> {
                         q = q.bind(Some(s.to_owned()));
                     }
                     serde_json::Value::Null => {
-                        q = q.bind(Option::<String>::None);
+                        q = q.bind(Option::<i32>::None);
                     }
                     serde_json::Value::Number(n) => {
                         if n.is_f64() {
